Oceanum python
==============

Python library for the `Oceanum.io`_ platform
---------------------------------------------

The oceanum python library provides a simple interface to `Oceanum.io`_, an advanced
cloud service for interacting with environmental data.

Documentation
-------------

**Contents:**

* :doc:`installation`
* :doc:`usage`
* :doc:`api`
* :doc:`about`


.. toctree::
   :maxdepth: 4
   :hidden:
   :caption: Contents:

   installation
   usage
   api
   about


.. _`Oceanum.io`: https://oceanum.io/
